@@ -21,26 +21,19 @@ Architecture:
 """
 
 import asyncio
-import subprocess
 import os
 import re
 import json
-import hashlib
 from pathlib import Path
 from typing import List, Dict, Any, Optional, Tuple, Set
 from dataclasses import dataclass, field
 from enum import Enum
-from datetime import datetime
-import fnmatch
 
 from rich.console import Console
 from rich.panel import Panel
-from rich.table import Table
 from rich.text import Text
-from rich.syntax import Syntax
-from rich.progress import Progress, SpinnerColumn, TextColumn
 
-from .theme import PRIMARY, CYAN, GREEN, GOLD, GRAY
+from .theme import PRIMARY, CYAN
 
 console = Console()
 
@@ -49,24 +42,26 @@ console = Console()
 # DATA STRUCTURES
 # ============================================================================
 
+
 class SearchStrategy(Enum):
-    RIPGREP = "ripgrep"      # Exact/regex text search
-    GLOB = "glob"            # File pattern matching
-    SYMBOL = "symbol"        # Function/class definitions
-    SEMANTIC = "semantic"    # Embedding-based similarity
-    MEMORY = "memory"        # Memory-guided search
+    RIPGREP = "ripgrep"  # Exact/regex text search
+    GLOB = "glob"  # File pattern matching
+    SYMBOL = "symbol"  # Function/class definitions
+    SEMANTIC = "semantic"  # Embedding-based similarity
+    MEMORY = "memory"  # Memory-guided search
 
 
 @dataclass
 class SearchResult:
     """A single search result with scoring."""
+
     file_path: str
     line_number: Optional[int] = None
     line_end: Optional[int] = None
     content: str = ""
-    match_type: str = ""           # What matched (pattern, symbol, etc.)
+    match_type: str = ""  # What matched (pattern, symbol, etc.)
     strategy: SearchStrategy = SearchStrategy.RIPGREP
-    score: float = 0.0             # Relevance score 0-1
+    score: float = 0.0  # Relevance score 0-1
     context_before: List[str] = field(default_factory=list)
     context_after: List[str] = field(default_factory=list)
 
@@ -82,6 +77,7 @@ class SearchResult:
 @dataclass
 class SearchQuery:
     """Parsed and analyzed search query."""
+
     raw_query: str
     keywords: List[str] = field(default_factory=list)
     file_patterns: List[str] = field(default_factory=list)
@@ -95,11 +91,12 @@ class SearchQuery:
 @dataclass
 class SearchConfig:
     """Configuration for search behavior."""
+
     max_results: int = 20
-    max_file_size: int = 100_000       # Skip files larger than 100KB
-    context_lines: int = 3              # Lines before/after match
-    parallel_limit: int = 8             # Max parallel searches
-    timeout_seconds: float = 10.0       # Per-strategy timeout
+    max_file_size: int = 100_000  # Skip files larger than 100KB
+    context_lines: int = 3  # Lines before/after match
+    parallel_limit: int = 8  # Max parallel searches
+    timeout_seconds: float = 10.0  # Per-strategy timeout
     include_hidden: bool = False
     respect_gitignore: bool = True
 
@@ -110,34 +107,34 @@ class SearchConfig:
 
 # Common programming language file extensions
 LANGUAGE_EXTENSIONS = {
-    'python': ['.py', '.pyw', '.pyi'],
-    'javascript': ['.js', '.jsx', '.mjs', '.cjs'],
-    'typescript': ['.ts', '.tsx', '.mts', '.cts'],
-    'rust': ['.rs'],
-    'go': ['.go'],
-    'java': ['.java'],
-    'cpp': ['.cpp', '.cc', '.cxx', '.hpp', '.h'],
-    'c': ['.c', '.h'],
-    'ruby': ['.rb', '.rake'],
-    'php': ['.php'],
-    'swift': ['.swift'],
-    'kotlin': ['.kt', '.kts'],
-    'scala': ['.scala'],
-    'shell': ['.sh', '.bash', '.zsh'],
+    "python": [".py", ".pyw", ".pyi"],
+    "javascript": [".js", ".jsx", ".mjs", ".cjs"],
+    "typescript": [".ts", ".tsx", ".mts", ".cts"],
+    "rust": [".rs"],
+    "go": [".go"],
+    "java": [".java"],
+    "cpp": [".cpp", ".cc", ".cxx", ".hpp", ".h"],
+    "c": [".c", ".h"],
+    "ruby": [".rb", ".rake"],
+    "php": [".php"],
+    "swift": [".swift"],
+    "kotlin": [".kt", ".kts"],
+    "scala": [".scala"],
+    "shell": [".sh", ".bash", ".zsh"],
 }
 
 # Patterns that indicate definition searches
 DEFINITION_PATTERNS = [
-    r'\bdef\s+(\w+)',           # Python function
-    r'\bclass\s+(\w+)',         # Class definition
-    r'\bfunction\s+(\w+)',      # JS/TS function
-    r'\bconst\s+(\w+)\s*=',     # JS/TS const
-    r'\binterface\s+(\w+)',     # TS interface
-    r'\btype\s+(\w+)\s*=',      # TS type alias
-    r'\bstruct\s+(\w+)',        # Rust/Go struct
-    r'\bimpl\s+(\w+)',          # Rust impl
-    r'\bfn\s+(\w+)',            # Rust function
-    r'\bfunc\s+(\w+)',          # Go function
+    r"\bdef\s+(\w+)",  # Python function
+    r"\bclass\s+(\w+)",  # Class definition
+    r"\bfunction\s+(\w+)",  # JS/TS function
+    r"\bconst\s+(\w+)\s*=",  # JS/TS const
+    r"\binterface\s+(\w+)",  # TS interface
+    r"\btype\s+(\w+)\s*=",  # TS type alias
+    r"\bstruct\s+(\w+)",  # Rust/Go struct
+    r"\bimpl\s+(\w+)",  # Rust impl
+    r"\bfn\s+(\w+)",  # Rust function
+    r"\bfunc\s+(\w+)",  # Go function
 ]
 
 
@@ -146,14 +143,18 @@ def analyze_query(raw_query: str) -> SearchQuery:
     query = SearchQuery(raw_query=raw_query)
 
     # Extract file patterns (e.g., "*.py", "src/**/*.ts")
-    file_pattern_regex = r'(\*\*?[/\\]?[\w.*/-]+|\w+\.\w+)'
+    file_pattern_regex = r"(\*\*?[/\\]?[\w.*/-]+|\w+\.\w+)"
     for match in re.finditer(file_pattern_regex, raw_query):
         pattern = match.group(1)
-        if '*' in pattern or '.' in pattern:
+        if "*" in pattern or "." in pattern:
             # Check if it looks like a file pattern
-            if any(pattern.endswith(ext) for exts in LANGUAGE_EXTENSIONS.values() for ext in exts):
+            if any(
+                pattern.endswith(ext)
+                for exts in LANGUAGE_EXTENSIONS.values()
+                for ext in exts
+            ):
                 query.file_patterns.append(pattern)
-            elif '*' in pattern:
+            elif "*" in pattern:
                 query.file_patterns.append(pattern)
 
     # Detect language hints
@@ -166,26 +167,67 @@ def analyze_query(raw_query: str) -> SearchQuery:
                 break
 
     # Detect definition search intent
-    definition_keywords = ['define', 'definition', 'where is', 'find class', 'find function', 'implementation']
+    definition_keywords = [
+        "define",
+        "definition",
+        "where is",
+        "find class",
+        "find function",
+        "implementation",
+    ]
     if any(kw in raw_query.lower() for kw in definition_keywords):
         query.is_definition_search = True
 
     # Detect usage search intent
-    usage_keywords = ['usage', 'used', 'called', 'imported', 'references']
+    usage_keywords = ["usage", "used", "called", "imported", "references"]
     if any(kw in raw_query.lower() for kw in usage_keywords):
         query.is_usage_search = True
 
     # Extract potential symbol names (CamelCase or snake_case identifiers)
-    symbol_regex = r'\b([A-Z][a-zA-Z0-9]*|[a-z][a-z0-9_]*[A-Z][a-zA-Z0-9]*|[a-z_][a-z0-9_]+)\b'
+    symbol_regex = (
+        r"\b([A-Z][a-zA-Z0-9]*|[a-z][a-z0-9_]*[A-Z][a-zA-Z0-9]*|[a-z_][a-z0-9_]+)\b"
+    )
     for match in re.finditer(symbol_regex, raw_query):
         symbol = match.group(1)
         # Filter out common words
-        if len(symbol) > 2 and symbol.lower() not in {'the', 'and', 'for', 'with', 'from', 'that', 'this'}:
+        if len(symbol) > 2 and symbol.lower() not in {
+            "the",
+            "and",
+            "for",
+            "with",
+            "from",
+            "that",
+            "this",
+        }:
             query.symbol_patterns.append(symbol)
 
     # Extract keywords (words not already captured)
-    words = re.findall(r'\b\w+\b', raw_query.lower())
-    stopwords = {'the', 'a', 'an', 'in', 'on', 'at', 'to', 'for', 'of', 'and', 'or', 'is', 'are', 'was', 'were', 'find', 'search', 'look', 'where', 'how', 'what', 'show', 'me'}
+    words = re.findall(r"\b\w+\b", raw_query.lower())
+    stopwords = {
+        "the",
+        "a",
+        "an",
+        "in",
+        "on",
+        "at",
+        "to",
+        "for",
+        "of",
+        "and",
+        "or",
+        "is",
+        "are",
+        "was",
+        "were",
+        "find",
+        "search",
+        "look",
+        "where",
+        "how",
+        "what",
+        "show",
+        "me",
+    }
     query.keywords = [w for w in words if w not in stopwords and len(w) > 2]
 
     return query
@@ -195,6 +237,7 @@ def analyze_query(raw_query: str) -> SearchQuery:
 # SEARCH STRATEGIES
 # ============================================================================
 
+
 async def ripgrep_search(
     patterns: List[str],
     root_path: str,
@@ -205,18 +248,18 @@ async def ripgrep_search(
     results = []
 
     async def search_pattern(pattern: str) -> List[SearchResult]:
-        cmd = ['rg', '--json', '-i', '--max-count=50']
+        cmd = ["rg", "--json", "-i", "--max-count=50"]
 
         if config.context_lines > 0:
-            cmd.extend(['-C', str(config.context_lines)])
+            cmd.extend(["-C", str(config.context_lines)])
 
         if config.respect_gitignore:
-            cmd.append('--hidden')
-            cmd.append('--glob=!.git')
+            cmd.append("--hidden")
+            cmd.append("--glob=!.git")
 
         if file_types:
             for ft in file_types:
-                cmd.extend(['--type', ft])
+                cmd.extend(["--type", ft])
 
         cmd.extend([pattern, root_path])
 
@@ -227,26 +270,29 @@ async def ripgrep_search(
                 stderr=asyncio.subprocess.DEVNULL,
             )
             stdout, _ = await asyncio.wait_for(
-                proc.communicate(),
-                timeout=config.timeout_seconds
+                proc.communicate(), timeout=config.timeout_seconds
             )
 
             pattern_results = []
-            for line in stdout.decode('utf-8', errors='ignore').splitlines():
+            for line in stdout.decode("utf-8", errors="ignore").splitlines():
                 if not line.strip():
                     continue
                 try:
                     data = json.loads(line)
-                    if data.get('type') == 'match':
-                        match_data = data.get('data', {})
-                        pattern_results.append(SearchResult(
-                            file_path=match_data.get('path', {}).get('text', ''),
-                            line_number=match_data.get('line_number'),
-                            content=match_data.get('lines', {}).get('text', '').strip(),
-                            match_type=f"pattern: {pattern}",
-                            strategy=SearchStrategy.RIPGREP,
-                            score=0.8,  # Base score for exact matches
-                        ))
+                    if data.get("type") == "match":
+                        match_data = data.get("data", {})
+                        pattern_results.append(
+                            SearchResult(
+                                file_path=match_data.get("path", {}).get("text", ""),
+                                line_number=match_data.get("line_number"),
+                                content=match_data.get("lines", {})
+                                .get("text", "")
+                                .strip(),
+                                match_type=f"pattern: {pattern}",
+                                strategy=SearchStrategy.RIPGREP,
+                                score=0.8,  # Base score for exact matches
+                            )
+                        )
                 except json.JSONDecodeError:
                     continue
 
@@ -260,7 +306,7 @@ async def ripgrep_search(
             return []
 
     # Run all patterns in parallel
-    tasks = [search_pattern(p) for p in patterns[:config.parallel_limit]]
+    tasks = [search_pattern(p) for p in patterns[: config.parallel_limit]]
     all_results = await asyncio.gather(*tasks)
 
     for pattern_results in all_results:
@@ -269,10 +315,12 @@ async def ripgrep_search(
     return results
 
 
-async def grep_fallback(pattern: str, root_path: str, config: SearchConfig) -> List[SearchResult]:
+async def grep_fallback(
+    pattern: str, root_path: str, config: SearchConfig
+) -> List[SearchResult]:
     """Fallback to grep if ripgrep isn't available."""
     results = []
-    cmd = ['grep', '-r', '-n', '-i', '--include=*.*', pattern, root_path]
+    cmd = ["grep", "-r", "-n", "-i", "--include=*.*", pattern, root_path]
 
     try:
         proc = await asyncio.create_subprocess_exec(
@@ -280,19 +328,23 @@ async def grep_fallback(pattern: str, root_path: str, config: SearchConfig) -> L
             stdout=asyncio.subprocess.PIPE,
             stderr=asyncio.subprocess.DEVNULL,
         )
-        stdout, _ = await asyncio.wait_for(proc.communicate(), timeout=config.timeout_seconds)
+        stdout, _ = await asyncio.wait_for(
+            proc.communicate(), timeout=config.timeout_seconds
+        )
 
-        for line in stdout.decode('utf-8', errors='ignore').splitlines()[:50]:
-            parts = line.split(':', 2)
+        for line in stdout.decode("utf-8", errors="ignore").splitlines()[:50]:
+            parts = line.split(":", 2)
             if len(parts) >= 3:
-                results.append(SearchResult(
-                    file_path=parts[0],
-                    line_number=int(parts[1]) if parts[1].isdigit() else None,
-                    content=parts[2].strip(),
-                    match_type=f"pattern: {pattern}",
-                    strategy=SearchStrategy.RIPGREP,
-                    score=0.7,
-                ))
+                results.append(
+                    SearchResult(
+                        file_path=parts[0],
+                        line_number=int(parts[1]) if parts[1].isdigit() else None,
+                        content=parts[2].strip(),
+                        match_type=f"pattern: {pattern}",
+                        strategy=SearchStrategy.RIPGREP,
+                        score=0.7,
+                    )
+                )
     except Exception:
         pass
 
@@ -308,13 +360,13 @@ async def glob_search(
     results = []
     root = Path(root_path)
 
-    for pattern in patterns[:config.parallel_limit]:
+    for pattern in patterns[: config.parallel_limit]:
         try:
             # Handle ** patterns
-            if '**' in pattern:
+            if "**" in pattern:
                 matches = list(root.glob(pattern))
             else:
-                matches = list(root.glob(f'**/{pattern}'))
+                matches = list(root.glob(f"**/{pattern}"))
 
             for match in matches[:20]:  # Limit per pattern
                 if match.is_file():
@@ -325,13 +377,15 @@ async def glob_search(
                     except OSError:
                         continue
 
-                    results.append(SearchResult(
-                        file_path=str(match),
-                        content=f"File: {match.name}",
-                        match_type=f"glob: {pattern}",
-                        strategy=SearchStrategy.GLOB,
-                        score=0.6,
-                    ))
+                    results.append(
+                        SearchResult(
+                            file_path=str(match),
+                            content=f"File: {match.name}",
+                            match_type=f"glob: {pattern}",
+                            strategy=SearchStrategy.GLOB,
+                            score=0.6,
+                        )
+                    )
         except Exception:
             continue
 
@@ -351,19 +405,21 @@ async def symbol_search(
     patterns = []
     for symbol in symbols:
         # Generic patterns that work across languages
-        patterns.extend([
-            f'def\\s+{symbol}\\s*\\(',           # Python function
-            f'class\\s+{symbol}[\\s:(]',          # Class
-            f'function\\s+{symbol}\\s*\\(',       # JS function
-            f'const\\s+{symbol}\\s*=',            # JS const
-            f'let\\s+{symbol}\\s*=',              # JS let
-            f'interface\\s+{symbol}[\\s{{<]',     # TS interface
-            f'type\\s+{symbol}\\s*=',             # TS type
-            f'fn\\s+{symbol}\\s*[<(]',            # Rust fn
-            f'struct\\s+{symbol}[\\s{{<]',        # Rust/Go struct
-            f'func\\s+{symbol}\\s*\\(',           # Go func
-            f'export\\s+(default\\s+)?{symbol}',  # JS export
-        ])
+        patterns.extend(
+            [
+                f"def\\s+{symbol}\\s*\\(",  # Python function
+                f"class\\s+{symbol}[\\s:(]",  # Class
+                f"function\\s+{symbol}\\s*\\(",  # JS function
+                f"const\\s+{symbol}\\s*=",  # JS const
+                f"let\\s+{symbol}\\s*=",  # JS let
+                f"interface\\s+{symbol}[\\s{{<]",  # TS interface
+                f"type\\s+{symbol}\\s*=",  # TS type
+                f"fn\\s+{symbol}\\s*[<(]",  # Rust fn
+                f"struct\\s+{symbol}[\\s{{<]",  # Rust/Go struct
+                f"func\\s+{symbol}\\s*\\(",  # Go func
+                f"export\\s+(default\\s+)?{symbol}",  # JS export
+            ]
+        )
 
     # Use ripgrep with these patterns
     rg_results = await ripgrep_search(patterns, root_path, config)
@@ -397,7 +453,7 @@ async def semantic_search_local(
 
     for ext_list in LANGUAGE_EXTENSIONS.values():
         for ext in ext_list:
-            for file_path in root.glob(f'**/*{ext}'):
+            for file_path in root.glob(f"**/*{ext}"):
                 if file_path.is_file():
                     try:
                         # Skip large files
@@ -405,7 +461,7 @@ async def semantic_search_local(
                             continue
 
                         # Quick content scan for keyword overlap
-                        content = file_path.read_text(encoding='utf-8', errors='ignore')
+                        content = file_path.read_text(encoding="utf-8", errors="ignore")
                         content_lower = content.lower()
 
                         # Score based on keyword presence
@@ -427,14 +483,16 @@ async def semantic_search_local(
     # Sort by score and take top results
     scored_files.sort(key=lambda x: -x[0])
 
-    for score, file_path in scored_files[:config.max_results]:
-        results.append(SearchResult(
-            file_path=str(file_path),
-            content=f"Semantic match: {file_path.name}",
-            match_type="semantic",
-            strategy=SearchStrategy.SEMANTIC,
-            score=min(0.7, score),  # Cap semantic scores
-        ))
+    for score, file_path in scored_files[: config.max_results]:
+        results.append(
+            SearchResult(
+                file_path=str(file_path),
+                content=f"Semantic match: {file_path.name}",
+                match_type="semantic",
+                strategy=SearchStrategy.SEMANTIC,
+                score=min(0.7, score),  # Cap semantic scores
+            )
+        )
 
     return results
 
@@ -443,6 +501,7 @@ async def semantic_search_local(
 # RESULT RANKING
 # ============================================================================
 
+
 def rank_results(results: List[SearchResult], query: SearchQuery) -> List[SearchResult]:
     """Rank and deduplicate search results."""
     # Deduplicate by file:line
@@ -460,7 +519,10 @@ def rank_results(results: List[SearchResult], query: SearchQuery) -> List[Search
         # Boost if file extension matches language hints
         if query.language_hints:
             for lang in query.language_hints:
-                if any(result.file_path.endswith(ext) for ext in LANGUAGE_EXTENSIONS.get(lang, [])):
+                if any(
+                    result.file_path.endswith(ext)
+                    for ext in LANGUAGE_EXTENSIONS.get(lang, [])
+                ):
                     result.score *= 1.2
 
         # Boost if symbol is in filename
@@ -469,8 +531,8 @@ def rank_results(results: List[SearchResult], query: SearchQuery) -> List[Search
                 result.score *= 1.3
 
         # Boost for test files if searching for tests
-        if 'test' in query.raw_query.lower():
-            if 'test' in result.file_path.lower():
+        if "test" in query.raw_query.lower():
+            if "test" in result.file_path.lower():
                 result.score *= 1.2
 
     # Sort by score descending
@@ -483,6 +545,7 @@ def rank_results(results: List[SearchResult], query: SearchQuery) -> List[Search
 # MAIN SEARCH ENGINE
 # ============================================================================
 
+
 class SynodSearchEngine:
     """Intelligent code search engine with parallel strategies."""
 
@@ -523,43 +586,51 @@ class SynodSearchEngine:
         tasks = []
 
         if SearchStrategy.RIPGREP in strategies and parsed.keywords:
-            tasks.append(ripgrep_search(
-                parsed.keywords[:5],  # Limit patterns
-                self.root_path,
-                self.config,
-            ))
+            tasks.append(
+                ripgrep_search(
+                    parsed.keywords[:5],  # Limit patterns
+                    self.root_path,
+                    self.config,
+                )
+            )
 
         if SearchStrategy.GLOB in strategies and parsed.file_patterns:
-            tasks.append(glob_search(
-                parsed.file_patterns,
-                self.root_path,
-                self.config,
-            ))
+            tasks.append(
+                glob_search(
+                    parsed.file_patterns,
+                    self.root_path,
+                    self.config,
+                )
+            )
 
         if SearchStrategy.SYMBOL in strategies and parsed.symbol_patterns:
-            tasks.append(symbol_search(
-                parsed.symbol_patterns,
-                self.root_path,
-                self.config,
-                parsed.language_hints,
-            ))
+            tasks.append(
+                symbol_search(
+                    parsed.symbol_patterns,
+                    self.root_path,
+                    self.config,
+                    parsed.language_hints,
+                )
+            )
 
         if SearchStrategy.SEMANTIC in strategies:
-            tasks.append(semantic_search_local(
-                query,
-                self.root_path,
-                self.config,
-            ))
+            tasks.append(
+                semantic_search_local(
+                    query,
+                    self.root_path,
+                    self.config,
+                )
+            )
 
         # Memory-guided search: use past memories to inform where to look
         if memories and SearchStrategy.MEMORY in strategies:
             memory_patterns = []
             for mem in memories:
                 # Extract file paths and patterns from memory content
-                content = mem.get('content', '')
-                if '/' in content or '\\' in content:
+                content = mem.get("content", "")
+                if "/" in content or "\\" in content:
                     # Might contain file paths
-                    path_match = re.search(r'[\w/\\.-]+\.\w+', content)
+                    path_match = re.search(r"[\w/\\.-]+\.\w+", content)
                     if path_match:
                         memory_patterns.append(path_match.group())
 
@@ -581,7 +652,7 @@ class SynodSearchEngine:
 
         # Rank and return
         ranked = rank_results(results, parsed)
-        return ranked[:self.config.max_results]
+        return ranked[: self.config.max_results]
 
     async def search_for_context(
         self,
@@ -611,7 +682,9 @@ class SynodSearchEngine:
                 context_parts.append(part)
                 total_chars += len(part)
 
-        context_str = "## Relevant Code\n" + "".join(context_parts) if context_parts else ""
+        context_str = (
+            "## Relevant Code\n" + "".join(context_parts) if context_parts else ""
+        )
 
         return results, context_str
 
@@ -620,18 +693,23 @@ class SynodSearchEngine:
 # CLI DISPLAY
 # ============================================================================
 
+
 def display_search_results(results: List[SearchResult], query: str) -> None:
     """Display search results with beautiful formatting."""
     if not results:
-        console.print(Panel(
-            Text("No results found", style="dim", justify="center"),
-            title=f"[cyan]Search: {query}[/cyan]",
-            border_style="cyan",
-        ))
+        console.print(
+            Panel(
+                Text("No results found", style="dim", justify="center"),
+                title=f"[cyan]Search: {query}[/cyan]",
+                border_style="cyan",
+            )
+        )
         return
 
     console.print()
-    console.print(Text(f"  Found {len(results)} results  ", style=f"bold white on {PRIMARY}"))
+    console.print(
+        Text(f"  Found {len(results)} results  ", style=f"bold white on {PRIMARY}")
+    )
     console.print()
 
     for i, result in enumerate(results[:15], 1):
@@ -670,19 +748,21 @@ async def interactive_search(root_path: str = ".") -> None:
     """Interactive search mode."""
     engine = SynodSearchEngine(root_path)
 
-    console.print(Panel(
-        Text.from_markup(
-            f"[{CYAN}]Synod Intelligent Code Search[/{CYAN}]\n\n"
-            f"Search across your codebase with parallel strategies.\n"
-            f"Type your query or 'exit' to quit."
-        ),
-        border_style=CYAN,
-    ))
+    console.print(
+        Panel(
+            Text.from_markup(
+                f"[{CYAN}]Synod Intelligent Code Search[/{CYAN}]\n\n"
+                f"Search across your codebase with parallel strategies.\n"
+                f"Type your query or 'exit' to quit."
+            ),
+            border_style=CYAN,
+        )
+    )
 
     while True:
         try:
             query = console.input(f"\n[{PRIMARY}]search>[/{PRIMARY}] ")
-            if query.lower() in ('exit', 'quit', 'q'):
+            if query.lower() in ("exit", "quit", "q"):
                 break
 
             if not query.strip():
@@ -705,6 +785,7 @@ async def interactive_search(root_path: str = ".") -> None:
 # COMMAND HANDLER
 # ============================================================================
 
+
 async def handle_search_command(args: str, root_path: str = ".") -> List[SearchResult]:
     """Handle /search command from CLI.
 
@@ -714,19 +795,21 @@ async def handle_search_command(args: str, root_path: str = ".") -> List[SearchR
         /search -f <pattern>      Search for files
     """
     if not args.strip():
-        console.print(Panel(
-            Text.from_markup(
-                f"[{CYAN}]/search <query>[/{CYAN}]      Search for code\n"
-                f"[{CYAN}]/search -d <name>[/{CYAN}]    Find definition\n"
-                f"[{CYAN}]/search -f <pattern>[/{CYAN}] Find files\n\n"
-                f"Examples:\n"
-                f"  /search rate limiting\n"
-                f"  /search -d UserService\n"
-                f"  /search -f *.test.ts"
-            ),
-            title="[cyan]Code Search[/cyan]",
-            border_style="cyan",
-        ))
+        console.print(
+            Panel(
+                Text.from_markup(
+                    f"[{CYAN}]/search <query>[/{CYAN}]      Search for code\n"
+                    f"[{CYAN}]/search -d <name>[/{CYAN}]    Find definition\n"
+                    f"[{CYAN}]/search -f <pattern>[/{CYAN}] Find files\n\n"
+                    f"Examples:\n"
+                    f"  /search rate limiting\n"
+                    f"  /search -d UserService\n"
+                    f"  /search -f *.test.ts"
+                ),
+                title="[cyan]Code Search[/cyan]",
+                border_style="cyan",
+            )
+        )
         return []
 
     engine = SynodSearchEngine(root_path)
@@ -735,11 +818,11 @@ async def handle_search_command(args: str, root_path: str = ".") -> List[SearchR
     strategies = None
     query = args.strip()
 
-    if query.startswith('-d '):
+    if query.startswith("-d "):
         # Definition search only
         query = query[3:]
         strategies = [SearchStrategy.SYMBOL]
-    elif query.startswith('-f '):
+    elif query.startswith("-f "):
         # File search only
         query = query[3:]
         strategies = [SearchStrategy.GLOB]
